import { type CustomRequestConfig } from '@sap-ai-sdk/core';
import { type ModelDeployment } from '@sap-ai-sdk/ai-api/internal.js';
import type { AzureOpenAiCreateChatCompletionRequest } from './client/inference/schema/index.js';
import { type AzureOpenAiChatModel } from './model-types.js';
import { AzureOpenAiChatCompletionResponse } from './azure-openai-chat-completion-response.js';
/**
 * Azure OpenAI client for chat completion.
 */
export declare class AzureOpenAiChatClient {
    private modelDeployment;
    /**
     * Creates an instance of the Azure OpenAI chat client.
     * @param modelDeployment - This configuration is used to retrieve a deployment. Depending on the configuration use either the given deployment ID or the model name to retrieve matching deployments. If model and deployment ID are given, the model is verified against the deployment.
     */
    constructor(modelDeployment: ModelDeployment<AzureOpenAiChatModel>);
    /**
     * Creates a completion for the chat messages.
     * @param data - The input parameters for the chat completion.
     * @param requestConfig - The request configuration.
     * @returns The completion result.
     */
    run(data: AzureOpenAiCreateChatCompletionRequest, requestConfig?: CustomRequestConfig): Promise<AzureOpenAiChatCompletionResponse>;
}
//# sourceMappingURL=azure-openai-chat-client.d.ts.map