import { executeRequest } from '@sap-ai-sdk/core';
import { getDeploymentId } from '@sap-ai-sdk/ai-api/internal.js';
import { apiVersion } from './model-types.js';
import { AzureOpenAiChatCompletionResponse } from './azure-openai-chat-completion-response.js';
/**
 * Azure OpenAI client for chat completion.
 */
export class AzureOpenAiChatClient {
    modelDeployment;
    /**
     * Creates an instance of the Azure OpenAI chat client.
     * @param modelDeployment - This configuration is used to retrieve a deployment. Depending on the configuration use either the given deployment ID or the model name to retrieve matching deployments. If model and deployment ID are given, the model is verified against the deployment.
     */
    constructor(modelDeployment) {
        this.modelDeployment = modelDeployment;
    }
    /**
     * Creates a completion for the chat messages.
     * @param data - The input parameters for the chat completion.
     * @param requestConfig - The request configuration.
     * @returns The completion result.
     */
    async run(data, requestConfig) {
        const deploymentId = await getDeploymentId(this.modelDeployment, 'azure-openai');
        const response = await executeRequest({
            url: `/inference/deployments/${deploymentId}/chat/completions`,
            apiVersion
        }, data, requestConfig);
        return new AzureOpenAiChatCompletionResponse(response);
    }
}
//# sourceMappingURL=azure-openai-chat-client.js.map