import { HttpResponse } from '@sap-cloud-sdk/http-client';
import type { AzureOpenAiCreateChatCompletionResponse } from './client/inference/schema/index.js';
/**
 * Azure OpenAI chat completion response.
 */
export declare class AzureOpenAiChatCompletionResponse {
    readonly rawResponse: HttpResponse;
    /**
     * The chat completion response.
     */
    readonly data: AzureOpenAiCreateChatCompletionResponse;
    constructor(rawResponse: HttpResponse);
    /**
     * Usage of tokens in the response.
     * @returns Token usage.
     */
    getTokenUsage(): this['data']['usage'];
    /**
     * Reason for stopping the completion.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The finish reason.
     */
    getFinishReason(choiceIndex?: number): this['data']['choices'][0]['finish_reason'];
    /**
     * Parses the Azure OpenAI response and returns the content.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The message content.
     */
    getContent(choiceIndex?: number): string | undefined | null;
    private logInvalidChoiceIndex;
}
//# sourceMappingURL=azure-openai-chat-completion-response.d.ts.map